@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,10 @@
 
 package com.openexchange.monitoring;
 
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicInteger;
+import com.openexchange.counter.Counter;
 
 /**
  * {@link MonitoringInfo} - Container for various monitoring information.
@@ -58,13 +61,23 @@ import java.util.concurrent.atomic.AtomicInteger;
  */
 public class MonitoringInfo {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MonitoringInfo.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MonitoringInfo.class));
 
     // Constants for connection types
+
+    /**
+     * The connection type constant for open AJP socket connections.
+     */
     public static final int AJP_SOCKET = 0;
 
+    /**
+     * The connection type constant for open connections/requests to AJAX interface.
+     */
     public static final int AJAX = 1;
 
+    /**
+     * The connection type constant for open connections/requests to Outlook WebDAV/XML interface.
+     */
     public static final int OUTLOOK = 2;
 
     public static final int WEBDAV_STORAGE = 3;
@@ -73,9 +86,20 @@ public class MonitoringInfo {
 
     public static final int SYNCML = 5;
 
+    /**
+     * The connection type constant for open connections to mail back-ends.
+     */
     public static final int IMAP = 6;
 
-    private static final int SESSION = 7;
+    /**
+     * The connection type constant for the number of open sessions.
+     */
+    public static final int SESSION = 7;
+
+    /**
+     * The connection type constant for the number of idling mail connections waiting for server notifications.
+     */
+    public static final int MAIL_IDLE = 8;
 
     /**
      * Unknown connection type
@@ -93,14 +117,34 @@ public class MonitoringInfo {
 
     private static final AtomicInteger numberOfSyncMLConnections = new AtomicInteger();
 
-    private static final AtomicInteger numberOfIMAPConnections = new AtomicInteger();
-
     private static final AtomicInteger numberOfActiveSessions = new AtomicInteger();
 
     private static int[] numberOfSessionsInContainer;
 
     private static final AtomicInteger numberOfRunningAJPListeners = new AtomicInteger();
 
+    private static final ConcurrentMap<Integer, Counter> COUNTER_MAP = new ConcurrentHashMap<Integer, Counter>(8);
+
+    private static final Counter EMPTY_COUNTER = new Counter() {
+        
+        public int getCount() {
+            return 0;
+        }
+    };
+
+    public static boolean putIfAbsent(final int connectionType, final Counter value) {
+        return null == COUNTER_MAP.putIfAbsent(Integer.valueOf(connectionType), value);
+    }
+
+    public static void remove(final int connectionType) {
+        COUNTER_MAP.remove(Integer.valueOf(connectionType));
+    }
+
+    private static Counter getCounter(final int connectionType) {
+        final Counter counter = COUNTER_MAP.get(Integer.valueOf(connectionType));
+        return null == counter ? EMPTY_COUNTER : counter;
+    }
+
     public static int getNumberOfActiveSessions() {
         return getNumberOfConnections(SESSION);
     }
@@ -135,10 +179,16 @@ public class MonitoringInfo {
         return numberOfOpenAJPSockets.get();
     }
 
+    /**
+     * Omit call to this method if <code>connectionType</code> is {@link #IMAP}.
+     */
     public static void incrementNumberOfConnections(final int connectionType) {
         changeNumberOfConnections(connectionType, true);
     }
 
+    /**
+     * Omit call to this method if <code>connectionType</code> is {@link #IMAP}.
+     */
     public static void decrementNumberOfConnections(final int connectionType) {
         changeNumberOfConnections(connectionType, false);
     }
@@ -168,11 +218,14 @@ public class MonitoringInfo {
             retval = numberOfSyncMLConnections.get();
             break;
         case IMAP:
-            retval = numberOfIMAPConnections.get();
+            retval = getCounter(connectionType).getCount();
             break;
         case SESSION:
             retval = numberOfActiveSessions.get();
             break;
+        case MAIL_IDLE:
+            retval = getCounter(connectionType).getCount();
+            break;
         default:
             LOG.error(new StringBuilder("MonitoringInfo.getNumberOfConnections(): Unknown connection type: ").append(connectionType).toString());
         }
@@ -217,11 +270,7 @@ public class MonitoringInfo {
             }
             break;
         case IMAP:
-            if (increment) {
-                numberOfIMAPConnections.incrementAndGet();
-            } else {
-                numberOfIMAPConnections.decrementAndGet();
-            }
+            // Nothing to do
             break;
         case SESSION:
             if (increment) {
@@ -230,6 +279,9 @@ public class MonitoringInfo {
                 numberOfActiveSessions.decrementAndGet();
             }
             break;
+        case MAIL_IDLE:
+            // Nothing to do
+            break;
         default:
             if (LOG.isInfoEnabled()) {
                 LOG.info(new StringBuilder("MonitoringInfo.changeNumberOfConnections(): Unknown connection type: ").append(connectionType).toString());
