@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,7 @@ import com.openexchange.sessiond.SessiondService;
  */
 public class GeneralMonitor implements GeneralMonitorMBean, MBeanRegistration {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(GeneralMonitor.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(GeneralMonitor.class));
 
     private MBeanServer server;
 
@@ -93,9 +93,8 @@ public class GeneralMonitor implements GeneralMonitorMBean, MBeanRegistration {
         return MonitoringInfo.getNumberOfConnections(MonitoringInfo.IMAP);
     }
 
-    public int getManuallyCountedIMAPConnections() {
-        // TODO: Add a member to trace MailAccess.getCounter();
-        return 0;
+    public int getNumberOfIdleMailConnections() {
+        return MonitoringInfo.getNumberOfConnections(MonitoringInfo.MAIL_IDLE);
     }
 
     public int getNumberOfActiveSessions() {
@@ -103,7 +102,10 @@ public class GeneralMonitor implements GeneralMonitorMBean, MBeanRegistration {
         if (sessiondService != null) {
             return sessiondService.getNumberOfActiveSessions();
         }
-        return -1;
+        /*
+         * No session can be active if service is missing
+         */
+        return 0;
     }
 
     public int getNumberOfRunningAJPListeners() {
